# Contributing
## Prerequisites
- Install `python`
- Fork the nikefy repo
- Run `git clone https://github.com/{username}/nikefy.git`
- In cloned repo, run `make develop`

## Contribute
Feel free to work on your own or existing issues with the project. Consider adding tests for any new features.

## Finish
When you are satisfied with your changes, please run the following:
- `make build`
- `make lint`
- `make checks`
- `make coverage`

Please add tests for any new features

## Pull Request
Commit your changes, push to your fork, and open a pull request to nikefy.
After a pull request is opened, I will review it and merge it with the main nikefy repo.